quantizationtools.QEvent
========================

.. inheritance-diagram:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.offset

.. autoattribute:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.value

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__eq__

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__repr__

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__str__

   .. note:: Inherited from `__builtin__.object`
